;; Generated package description from consult-denote.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "consult-denote" "0.4.1.0.20251118.174206" "Use Consult in tandem with Denote" '((emacs "28.1") (denote "4.0.0") (consult "2.2")) :commit "5800b4d9e74b362fdca0f2986a7d34f65ed4bd41" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/consult-denote")
